@@ -6,8 +6,8 @@
 ;; Author: Campbell Barton <ideasman42@gmail.com>
 
 ;; URL: https://codeberg.org/ideasman42/emacs-scroll-on-jump
-;; Package-Version: 20250913.2251
-;; Package-Revision: 6b992a611a09
+;; Package-Version: 20251126.514
+;; Package-Revision: ffb6fbfda84a
 ;; Package-Requires: ((emacs "26.2"))
 
 ;;; Commentary:
@@ -286,7 +286,7 @@ Moving the point when ALSO-MOVE-POINT is set."
 
     ;; Animated scrolling (early exit on input to avoid annoying lag).
     (cond
-     ((not (zerop lines-scroll))
+     ((null (zerop lines-scroll))
       (let ((is-early-exit t)
             (lines-done-abs 0)
             (lines-scroll-abs (abs lines-scroll))
@@ -331,7 +331,7 @@ Moving the point when ALSO-MOVE-POINT is set."
             (setq is-early-exit nil)))
 
         ;; Re-enable when editing logic.
-        (when (and (null is-early-exit) (not (zerop lines-scroll)))
+        (when (and (null is-early-exit) (null (zerop lines-scroll)))
           (error "Internal error, 'lines-scroll' should be zero"))
 
         ;; If we exit early because of input.
@@ -362,7 +362,7 @@ Argument ALSO-MOVE-POINT moves the point while scrolling."
 
     ;; Animated scrolling (early exit on input to avoid annoying lag).
     (cond
-     ((not (zerop lines-scroll))
+     ((null (zerop lines-scroll))
       (let ((is-early-exit t)
             (px-done-abs 0)
             (px-scroll-abs (abs (* lines-scroll char-height)))
@@ -428,12 +428,12 @@ Argument ALSO-MOVE-POINT moves the point while scrolling."
             (scroll-on-jump--scroll-by-lines-simple window lines-scroll nil))
 
            ;; Sanity check, if this fails there is an issue with internal logic.
-           ((not (zerop px-scroll))
+           ((null (zerop px-scroll))
             (set-window-vscroll window 0 t)
             (error "Internal error, 'px-scroll' should be zero"))
 
            ;; Also should never happen.
-           ((not (zerop (window-vscroll window t)))
+           ((null (zerop (window-vscroll window t)))
             (set-window-vscroll window 0 t)
             (message "Warning, sub-pixel scroll left set!"))))))
 
@@ -529,7 +529,7 @@ Moving the point when ALSO-MOVE-POINT is set."
                          (goto-char (window-start window))
                          (forward-line lines-scroll))))))))
 
-        (let ((also-move-point (not (eq (point) point-next))))
+        (let ((also-move-point (null (eq (point) point-next))))
           (scroll-on-jump--scroll-impl window lines-scroll dir also-move-point)))))
 
   (goto-char point-next))
@@ -590,7 +590,7 @@ Argument USE-WINDOW-START detects window scrolling when non-nil."
 
       (cond
        ;; Context changed or recursed, simply jump.
-       ((not
+       ((null
          ;; Check if the buffer/context changed.
          (and (eq buf (window-buffer window))
               (eq buf (current-buffer))
@@ -618,7 +618,7 @@ Argument USE-WINDOW-START detects window scrolling when non-nil."
                      1)
                     (t
                      -1)))
-                  (also-move-point (not (eq (point) point-next))))
+                  (also-move-point (null (eq (point) point-next))))
               (scroll-on-jump--scroll-impl window (* dir lines-scroll) dir also-move-point)))
           (prog1 (goto-char point-next)
             (redisplay t)))
